@@ -280,7 +280,7 @@ class Evaluators:
 
     def find_cut(self):
         
-        cut_df = pd.DataFrame(columns = {'Cut', 'Precision', 'Recall', 'F1',  'Count'})
+        cut_df = pd.DataFrame(columns = {'Cut', 'Precision', 'Recall', 'F1',  'Positive Count'})
         
         for i in range(0,20):
             
@@ -290,13 +290,26 @@ class Evaluators:
             fn = self.df.loc[(self.df['True'] == 1) & (self.df['Pred'] <  cut)]
             fp = self.df.loc[(self.df['True'] == 0) & (self.df['Pred'] >= cut)]
             
+            # Cutting point           
             cut_df.at[i, 'Cut']       = round(cut, 2)
-            cut_df.at[i, 'Precision'] = round((tp.shape[0] / (tp.shape[0] + fp.shape[0]))* 100, 2)
-            cut_df.at[i, 'Recall']    = round((tp.shape[0] / (tp.shape[0] + fn.shape[0]))* 100, 2)
-            cut_df.at[i, 'F1']        = round((tp.shape[0] / (tp.shape[0] + (0.5 * (fp.shape[0] + fn.shape[0]))))* 100, 2)
-            cut_df.at[i, 'Count']     = self.df[self.df['Pred'] >= cut].shape[0]
             
-        cut_df = cut_df[['Cut', 'Count','Precision','Recall','F1']].set_index('Cut')
+            # Precision
+            if fp.shape[0] == 0:
+                cut_df.at[i, 'Precision'] == 'undefined'
+                
+            else:
+                cut_df.at[i, 'Precision'] = round((tp.shape[0] / (tp.shape[0] + fp.shape[0]))* 100, 2)
+            
+            # Recall
+            cut_df.at[i, 'Recall']    = round((tp.shape[0] / (tp.shape[0] + fn.shape[0]))* 100, 2)
+            
+            # F1
+            cut_df.at[i, 'F1']        = round((tp.shape[0] / (tp.shape[0] + (0.5 * (fp.shape[0] + fn.shape[0]))))* 100, 2)
+            
+            # Positive count
+            cut_df.at[i, 'Positive Count']     = self.df[self.df['Pred'] >= cut].shape[0]
+            
+        cut_df = cut_df[['Cut', 'Positive Count','Precision','Recall','F1']].set_index('Cut')
         self.cut_df = cut_df
             
         return cut_df
\ No newline at end of file
